==> commons-iterables-1.1.2-sources.jar: net/markenwerk/commons/iterables/BooleanArrayIterable.java <==
/*
 * Copyright (c) 2015 Torsten Krause, Markenwerk GmbH
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.markenwerk.commons.iterables;

import java.util.Iterator;

import net.markenwerk.commons.iterators.BooleanArrayIterator;

/**
 * An {@link BooleanArrayIterable} is a {@link Iterable} that generates
 * {@link Iterator Iterators} that iterate over a given {@code boolean[]}.
 * 
 * <p>
 * Calling {@link BooleanArrayIterable#iterator()} creates an instance of
 * {@link BooleanArrayIterator}.
 * 
 * @author Torsten Krause (tk at markenwerk dot net)
 * @since 1.0.0
 */
public final class BooleanArrayIterable implements Iterable<Boolean> {

	private final boolean[] values;

	private final Boolean replacement;

	/**
	 * Creates a new {@link BooleanArrayIterable} for the given
	 * {@code boolean[]}.
	 * 
	 * @param values
	 *            The {@code boolean[]} to iterate over.
	 */
	public BooleanArrayIterable(boolean[] values) {
		this(values, null);
	}

	/**
	 * Creates a new {@link BooleanArrayIterable} for the given
	 * {@code boolean[]}.
	 * 
	 * @param values
	 *            The {@code boolean[]} to iterate over.
	 * @param replacement
	 *            The value to replace removed values with.
	 */
	public BooleanArrayIterable(boolean[] values, boolean replacement) {
		this(values, Boolean.valueOf(replacement));
	}

	private BooleanArrayIterable(boolean[] values, Boolean replacement) {
		this.values = values;
		this.replacement = replacement;
	}

	@Override
	public Iterator<Boolean> iterator() {
		return null != replacement ? new BooleanArrayIterator(values, replacement) : new BooleanArrayIterator(values);
	}

}

==> commons-iterables-2.0.0-sources.jar: net/markenwerk/commons/iterables/BooleanArrayIterable.java <==
/*
 * Copyright (c) 2015 Torsten Krause, Markenwerk GmbH
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.markenwerk.commons.iterables;

import java.util.Iterator;

import net.markenwerk.commons.iterators.BooleanArrayIterator;

/**
 * An {@link BooleanArrayIterable} is a {@link Iterable} that generates
 * {@link Iterator Iterators} that iterate over a given {@code boolean[]}.
 * 
 * <p>
 * Calling {@link BooleanArrayIterable#iterator()} creates an instance of
 * {@link BooleanArrayIterator}.
 * 
 * @author Torsten Krause (tk at markenwerk dot net)
 * @since 1.0.0
 */
public final class BooleanArrayIterable implements Iterable<Boolean> {

	private final boolean[] array;

	private final Boolean replacement;

	/**
	 * Creates a new {@link BooleanArrayIterable} for the given
	 * {@code boolean[]}.
	 * 
	 * @param array
	 *            The {@code boolean[]} to iterate over.
	 * 
	 * @throws IllegalArgumentException
	 *             If the given {@code boolean[]} is {@literal null}.
	 */
	public BooleanArrayIterable(boolean[] array) throws IllegalArgumentException {
		this(array, null);
	}

	/**
	 * Creates a new {@link BooleanArrayIterable} for the given
	 * {@code boolean[]}.
	 * 
	 * @param array
	 *            The {@code boolean[]} to iterate over.
	 * @param replacement
	 *            The value to replace removed array with.
	 * 
	 * @throws IllegalArgumentException
	 *             If the given {@code boolean[]} is {@literal null}.
	 */
	public BooleanArrayIterable(boolean[] array, boolean replacement) throws IllegalArgumentException {
		this(array, Boolean.valueOf(replacement));
	}

	private BooleanArrayIterable(boolean[] array, Boolean replacement) throws IllegalArgumentException {
		if (null == array) {
			throw new IllegalArgumentException("array is null");
		}
		this.array = array;
		this.replacement = replacement;
	}

	@Override
	public BooleanArrayIterator iterator() {
		return null != replacement ? new BooleanArrayIterator(array, replacement) : new BooleanArrayIterator(array);
	}

}
